==> tutti-ui-swing-1.0-sources.jar: fr/ifremer/tutti/ui/swing/content/operation/catches/plankton/PlanktonBatchTableModel.java <==
package fr.ifremer.tutti.ui.swing.content.operation.catches.plankton;

/*
 * #%L
 * Tutti :: UI
 * $Id: PlanktonBatchTableModel.java 135 2013-01-01 16:10:44Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.0/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/operation/catches/plankton/PlanktonBatchTableModel.java $
 * %%
 * Copyright (C) 2012 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.ui.swing.util.table.AbstractTuttiTableModel;
import fr.ifremer.tutti.ui.swing.util.table.ColumnIdentifier;

import javax.swing.table.TableColumnModel;

import static org.nuiton.i18n.I18n.n_;

/**
 * @author tchemit <chemit@codelutin.com>
 * @since 0.2
 */
public class PlanktonBatchTableModel extends AbstractTuttiTableModel<PlanktonBatchRowModel> {

    private static final long serialVersionUID = 1L;

    public static final ColumnIdentifier<PlanktonBatchRowModel> SPECIES_TO_CONFIRM = ColumnIdentifier.newId(
            PlanktonBatchRowModel.PROPERTY_SPECIES_TO_CONFIRM,
            n_("tutti.table.plankton.batch.header.toConfirm"),
            n_("tutti.table.plankton.batch.header.toConfirm"));

    public static final ColumnIdentifier<PlanktonBatchRowModel> SPECIES_BY_CODE = ColumnIdentifier.newId(
            PlanktonBatchRowModel.PROPERTY_SPECIES,
            n_("tutti.table.plankton.batch.header.speciesByCode"),
            n_("tutti.table.plankton.batch.header.speciesByCode"));

    public static final ColumnIdentifier<PlanktonBatchRowModel> SPECIES_BY_GENUS_CODE = ColumnIdentifier.newId(
            PlanktonBatchRowModel.PROPERTY_SPECIES,
            n_("tutti.table.plankton.batch.header.speciesByGenusCode"),
            n_("tutti.table.plankton.batch.header.speciesByGenusCode"));

    public static final ColumnIdentifier<PlanktonBatchRowModel> WEIGHT = ColumnIdentifier.newId(
            PlanktonBatchRowModel.PROPERTY_WEIGHT,
            n_("tutti.table.plankton.batch.header.weight"),
            n_("tutti.table.plankton.batch.header.weight"));

    public static final ColumnIdentifier<PlanktonBatchRowModel> SAMPLE_WEIGHT = ColumnIdentifier.newId(
            PlanktonBatchRowModel.PROPERTY_SAMPLE_WEIGHT,
            n_("tutti.table.plankton.batch.header.sampleWeight"),
            n_("tutti.table.plankton.batch.header.sampleWeight"));

    public static final ColumnIdentifier<PlanktonBatchRowModel> COMMENT = ColumnIdentifier.newId(
            PlanktonBatchRowModel.PROPERTY_COMMENT,
            n_("tutti.table.plankton.batch.header.comment"),
            n_("tutti.table.plankton.batch.header.comment"));

    public static final ColumnIdentifier<PlanktonBatchRowModel> ATTACHMENTS = ColumnIdentifier.newId(
            PlanktonBatchRowModel.PROPERTY_ATTACHMENTS,
            n_("tutti.table.plankton.batch.header.file"),
            n_("tutti.table.plankton.batch.header.file"));

    public PlanktonBatchTableModel(TableColumnModel columnModel) {
        super(columnModel, true, true);
        setNoneEditableCols();
    }

    @Override
    public PlanktonBatchRowModel createNewRow() {
        PlanktonBatchRowModel result = new PlanktonBatchRowModel();

        // by default empty row is not valid
        result.setValid(false);
        return result;
    }

    @Override
    public void setValueAt(Object aValue,
                           int rowIndex,
                           int columnIndex,
                           ColumnIdentifier<PlanktonBatchRowModel> propertyName,
                           PlanktonBatchRowModel entry) {
        super.setValueAt(aValue, rowIndex, columnIndex, propertyName, entry);

        if (propertyName == SPECIES_BY_CODE) {

            // update also other columns
            fireTableCellUpdated(rowIndex, SPECIES_BY_GENUS_CODE);

        } else if (propertyName == SPECIES_BY_GENUS_CODE) {

            // update also other columns
            fireTableCellUpdated(rowIndex, SPECIES_BY_CODE);
        }
    }

}

==> tutti-ui-swing-1.0.1-sources.jar: fr/ifremer/tutti/ui/swing/content/operation/catches/plankton/PlanktonBatchTableModel.java <==
package fr.ifremer.tutti.ui.swing.content.operation.catches.plankton;

/*
 * #%L
 * Tutti :: UI
 * $Id: PlanktonBatchTableModel.java 135 2013-01-01 16:10:44Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.0.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/operation/catches/plankton/PlanktonBatchTableModel.java $
 * %%
 * Copyright (C) 2012 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.ui.swing.util.table.AbstractTuttiTableModel;
import fr.ifremer.tutti.ui.swing.util.table.ColumnIdentifier;

import javax.swing.table.TableColumnModel;

import static org.nuiton.i18n.I18n.n_;

/**
 * @author tchemit <chemit@codelutin.com>
 * @since 0.2
 */
public class PlanktonBatchTableModel extends AbstractTuttiTableModel<PlanktonBatchRowModel> {

    private static final long serialVersionUID = 1L;

    public static final ColumnIdentifier<PlanktonBatchRowModel> SPECIES_TO_CONFIRM = ColumnIdentifier.newId(
            PlanktonBatchRowModel.PROPERTY_SPECIES_TO_CONFIRM,
            n_("tutti.table.plankton.batch.header.toConfirm"),
            n_("tutti.table.plankton.batch.header.toConfirm"));

    public static final ColumnIdentifier<PlanktonBatchRowModel> SPECIES_BY_CODE = ColumnIdentifier.newId(
            PlanktonBatchRowModel.PROPERTY_SPECIES,
            n_("tutti.table.plankton.batch.header.speciesByCode"),
            n_("tutti.table.plankton.batch.header.speciesByCode"));

    public static final ColumnIdentifier<PlanktonBatchRowModel> SPECIES_BY_GENUS_CODE = ColumnIdentifier.newId(
            PlanktonBatchRowModel.PROPERTY_SPECIES,
            n_("tutti.table.plankton.batch.header.speciesByGenusCode"),
            n_("tutti.table.plankton.batch.header.speciesByGenusCode"));

    public static final ColumnIdentifier<PlanktonBatchRowModel> WEIGHT = ColumnIdentifier.newId(
            PlanktonBatchRowModel.PROPERTY_WEIGHT,
            n_("tutti.table.plankton.batch.header.weight"),
            n_("tutti.table.plankton.batch.header.weight"));

    public static final ColumnIdentifier<PlanktonBatchRowModel> SAMPLE_WEIGHT = ColumnIdentifier.newId(
            PlanktonBatchRowModel.PROPERTY_SAMPLE_WEIGHT,
            n_("tutti.table.plankton.batch.header.sampleWeight"),
            n_("tutti.table.plankton.batch.header.sampleWeight"));

    public static final ColumnIdentifier<PlanktonBatchRowModel> COMMENT = ColumnIdentifier.newId(
            PlanktonBatchRowModel.PROPERTY_COMMENT,
            n_("tutti.table.plankton.batch.header.comment"),
            n_("tutti.table.plankton.batch.header.comment"));

    public static final ColumnIdentifier<PlanktonBatchRowModel> ATTACHMENTS = ColumnIdentifier.newId(
            PlanktonBatchRowModel.PROPERTY_ATTACHMENTS,
            n_("tutti.table.plankton.batch.header.file"),
            n_("tutti.table.plankton.batch.header.file"));

    public PlanktonBatchTableModel(TableColumnModel columnModel) {
        super(columnModel, true, true);
        setNoneEditableCols();
    }

    @Override
    public PlanktonBatchRowModel createNewRow() {
        PlanktonBatchRowModel result = new PlanktonBatchRowModel();

        // by default empty row is not valid
        result.setValid(false);
        return result;
    }

    @Override
    public void setValueAt(Object aValue,
                           int rowIndex,
                           int columnIndex,
                           ColumnIdentifier<PlanktonBatchRowModel> propertyName,
                           PlanktonBatchRowModel entry) {
        super.setValueAt(aValue, rowIndex, columnIndex, propertyName, entry);

        if (propertyName == SPECIES_BY_CODE) {

            // update also other columns
            fireTableCellUpdated(rowIndex, SPECIES_BY_GENUS_CODE);

        } else if (propertyName == SPECIES_BY_GENUS_CODE) {

            // update also other columns
            fireTableCellUpdated(rowIndex, SPECIES_BY_CODE);
        }
    }

}
